2021-09-10 Version: 1.1.0
- Generated python2 2020-05-18 for dataworks-public.

2021-08-20 Version: 1.0.1
- Generated python2 2020-05-18 for dataworks-public.

2021-05-20 Version: 1.0.0
- Generated python2 2020-05-18 for dataworks-public.

